// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef AKONADINOTES_VERSION_H
#define AKONADINOTES_VERSION_H

#define AKONADINOTES_VERSION_STRING "5.24.5"
#define AKONADINOTES_VERSION_MAJOR 5
#define AKONADINOTES_VERSION_MINOR 24
#define AKONADINOTES_VERSION_PATCH 5
#define AKONADINOTES_VERSION ((5<<16)|(24<<8)|(5))

#endif
